# tiledb-cloud
TileDB Storage Platform REST API

The `rest_api` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.2.19
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.15
* six >= 1.10
* certifi
* python-dateutil

## Getting Started

In your own code, to use this library to connect and interact with tiledb-cloud,
you can run the following:

```python
from __future__ import print_function

import time
import tiledb.cloud.rest_api
from tiledb.cloud.rest_api.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = tiledb.cloud.rest_api.Configuration(
    host = "http://localhost/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKeyAuth
configuration = tiledb.cloud.rest_api.Configuration(
    host = "http://localhost/v1",
    api_key = {
        'X-TILEDB-REST-API-KEY': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-TILEDB-REST-API-KEY'] = 'Bearer'

# Configure HTTP basic authorization: BasicAuth
configuration = tiledb.cloud.rest_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)


# Enter a context with an instance of the API client
with tiledb.cloud.rest_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = tiledb.cloud.rest_api.ArrayApi(api_client)
    namespace = 'namespace_example' # str | namespace array is in (an organization name or user's username)
array = 'array_example' # str | name/uri of array that is url-encoded
start = 56 # int | Start time of window of fetch logs, unix epoch in seconds (default: seven days ago) (optional)
end = 56 # int | End time of window of fetch logs, unix epoch in seconds (default: current utc timestamp) (optional)
event_types = 'event_types_example' # str | Event values can be one or more of the following read, write, create, delete, register, deregister, comma separated (optional)
task_id = 'task_id_example' # str | Array task ID To filter activity to (optional)
has_task_id = True # bool | Excludes activity log results that do not contain an array task UUID (optional)

    try:
        api_response = api_instance.array_activity_log(namespace, array, start=start, end=end, event_types=event_types, task_id=task_id, has_task_id=has_task_id)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ArrayApi->array_activity_log: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ArrayApi* | [**array_activity_log**](docs/ArrayApi.md#array_activity_log) | **GET** /arrays/{namespace}/{array}/activity | 
*ArrayApi* | [**arrays_browser_owned_get**](docs/ArrayApi.md#arrays_browser_owned_get) | **GET** /arrays/browser/owned | 
*ArrayApi* | [**arrays_browser_owned_sidebar_get**](docs/ArrayApi.md#arrays_browser_owned_sidebar_get) | **GET** /arrays/browser/owned/sidebar | 
*ArrayApi* | [**arrays_browser_public_get**](docs/ArrayApi.md#arrays_browser_public_get) | **GET** /arrays/browser/public | 
*ArrayApi* | [**arrays_browser_public_sidebar_get**](docs/ArrayApi.md#arrays_browser_public_sidebar_get) | **GET** /arrays/browser/public/sidebar | 
*ArrayApi* | [**arrays_browser_shared_get**](docs/ArrayApi.md#arrays_browser_shared_get) | **GET** /arrays/browser/shared | 
*ArrayApi* | [**arrays_browser_shared_sidebar_get**](docs/ArrayApi.md#arrays_browser_shared_sidebar_get) | **GET** /arrays/browser/shared/sidebar | 
*ArrayApi* | [**arrays_namespace_array_end_timestamps_get**](docs/ArrayApi.md#arrays_namespace_array_end_timestamps_get) | **GET** /arrays/{namespace}/{array}/end_timestamps | 
*ArrayApi* | [**consolidate_array**](docs/ArrayApi.md#consolidate_array) | **POST** /arrays/{namespace}/{array}/consolidate | 
*ArrayApi* | [**create_array**](docs/ArrayApi.md#create_array) | **POST** /arrays/{namespace}/{array} | 
*ArrayApi* | [**delete_array**](docs/ArrayApi.md#delete_array) | **DELETE** /arrays/{namespace}/{array} | 
*ArrayApi* | [**deregister_array**](docs/ArrayApi.md#deregister_array) | **DELETE** /arrays/{namespace}/{array}/deregister | 
*ArrayApi* | [**get_activity_log_by_id**](docs/ArrayApi.md#get_activity_log_by_id) | **GET** /arrays/{namespace}/{array}/activity/{id} | 
*ArrayApi* | [**get_all_array_metadata**](docs/ArrayApi.md#get_all_array_metadata) | **GET** /arrays | 
*ArrayApi* | [**get_array**](docs/ArrayApi.md#get_array) | **GET** /arrays/{namespace}/{array} | 
*ArrayApi* | [**get_array_max_buffer_sizes**](docs/ArrayApi.md#get_array_max_buffer_sizes) | **GET** /arrays/{namespace}/{array}/max_buffer_sizes | 
*ArrayApi* | [**get_array_meta_data_json**](docs/ArrayApi.md#get_array_meta_data_json) | **GET** /arrays/{namespace}/{array}/metadata_json | 
*ArrayApi* | [**get_array_metadata**](docs/ArrayApi.md#get_array_metadata) | **GET** /arrays/{namespace}/{array}/metadata | 
*ArrayApi* | [**get_array_metadata_capnp**](docs/ArrayApi.md#get_array_metadata_capnp) | **GET** /arrays/{namespace}/{array}/array_metadata | 
*ArrayApi* | [**get_array_non_empty_domain**](docs/ArrayApi.md#get_array_non_empty_domain) | **GET** /arrays/{namespace}/{array}/non_empty_domain | 
*ArrayApi* | [**get_array_non_empty_domain_json**](docs/ArrayApi.md#get_array_non_empty_domain_json) | **GET** /arrays/{namespace}/{array}/non_empty_domain_json | 
*ArrayApi* | [**get_array_sample_data**](docs/ArrayApi.md#get_array_sample_data) | **GET** /arrays/{namespace}/{array}/sample | 
*ArrayApi* | [**get_array_sharing_policies**](docs/ArrayApi.md#get_array_sharing_policies) | **GET** /arrays/{namespace}/{array}/share | 
*ArrayApi* | [**get_arrays_in_namespace**](docs/ArrayApi.md#get_arrays_in_namespace) | **GET** /arrays/{namespace} | 
*ArrayApi* | [**get_fragment_end_timestamp**](docs/ArrayApi.md#get_fragment_end_timestamp) | **GET** /arrays/{namespace}/{array}/fragment_end_timestamp | 
*ArrayApi* | [**get_last_accessed_arrays**](docs/ArrayApi.md#get_last_accessed_arrays) | **GET** /arrays/last_accessed | 
*ArrayApi* | [**register_array**](docs/ArrayApi.md#register_array) | **POST** /arrays/{namespace}/{array}/register | 
*ArrayApi* | [**share_array**](docs/ArrayApi.md#share_array) | **PATCH** /arrays/{namespace}/{array}/share | 
*ArrayApi* | [**update_array_metadata**](docs/ArrayApi.md#update_array_metadata) | **PATCH** /arrays/{namespace}/{array}/metadata | 
*ArrayApi* | [**update_array_metadata_capnp**](docs/ArrayApi.md#update_array_metadata_capnp) | **POST** /arrays/{namespace}/{array}/array_metadata | 
*ArrayApi* | [**vacuum_array**](docs/ArrayApi.md#vacuum_array) | **POST** /arrays/{namespace}/{array}/vacuum | 
*ArrayTasksApi* | [**get_array_tasks_sidebar**](docs/ArrayTasksApi.md#get_array_tasks_sidebar) | **GET** /tasks/sidebar | 
*FavoritesApi* | [**add_array_favorite**](docs/FavoritesApi.md#add_array_favorite) | **POST** /arrays/favorites/{namespace}/{name} | 
*FavoritesApi* | [**add_ml_model_favorite**](docs/FavoritesApi.md#add_ml_model_favorite) | **POST** /ml_models/favorites/{namespace}/{name} | 
*FavoritesApi* | [**add_notebook_favorite**](docs/FavoritesApi.md#add_notebook_favorite) | **POST** /notebooks/favorites/{namespace}/{name} | 
*FavoritesApi* | [**add_udf_favorite**](docs/FavoritesApi.md#add_udf_favorite) | **POST** /udfs/favorites/{namespace}/{name} | 
*FavoritesApi* | [**delete_array_favorite**](docs/FavoritesApi.md#delete_array_favorite) | **DELETE** /arrays/favorites/{namespace}/{name} | 
*FavoritesApi* | [**delete_ml_model_favorite**](docs/FavoritesApi.md#delete_ml_model_favorite) | **DELETE** /ml_models/favorites/{namespace}/{name} | 
*FavoritesApi* | [**delete_notebook_favorite**](docs/FavoritesApi.md#delete_notebook_favorite) | **DELETE** /notebooks/favorites/{namespace}/{name} | 
*FavoritesApi* | [**delete_udf_favorite**](docs/FavoritesApi.md#delete_udf_favorite) | **DELETE** /udfs/favorites/{namespace}/{name} | 
*FavoritesApi* | [**get_array_favorite**](docs/FavoritesApi.md#get_array_favorite) | **GET** /arrays/favorites/{namespace}/{name} | 
*FavoritesApi* | [**get_ml_model_favorite**](docs/FavoritesApi.md#get_ml_model_favorite) | **GET** /ml_models/favorites/{namespace}/{name} | 
*FavoritesApi* | [**get_notebook_favorite**](docs/FavoritesApi.md#get_notebook_favorite) | **GET** /notebooks/favorites/{namespace}/{name} | 
*FavoritesApi* | [**get_udf_favorite**](docs/FavoritesApi.md#get_udf_favorite) | **GET** /udfs/favorites/{namespace}/{name} | 
*FavoritesApi* | [**list_array_favorites**](docs/FavoritesApi.md#list_array_favorites) | **GET** /arrays/favorites | 
*FavoritesApi* | [**list_array_favorites_uui_ds**](docs/FavoritesApi.md#list_array_favorites_uui_ds) | **GET** /arrays/favorites/uuids | 
*FavoritesApi* | [**list_ml_model_favorites**](docs/FavoritesApi.md#list_ml_model_favorites) | **GET** /ml_models/favorites | 
*FavoritesApi* | [**list_ml_model_favorites_uui_ds**](docs/FavoritesApi.md#list_ml_model_favorites_uui_ds) | **GET** /ml_models/favorites/uuids | 
*FavoritesApi* | [**list_notebook_favorites**](docs/FavoritesApi.md#list_notebook_favorites) | **GET** /notebooks/favorites | 
*FavoritesApi* | [**list_notebook_favorites_uui_ds**](docs/FavoritesApi.md#list_notebook_favorites_uui_ds) | **GET** /notebooks/favorites/uuids | 
*FavoritesApi* | [**list_udf_favorites**](docs/FavoritesApi.md#list_udf_favorites) | **GET** /udfs/favorites | 
*FavoritesApi* | [**list_udf_favorites_uui_ds**](docs/FavoritesApi.md#list_udf_favorites_uui_ds) | **GET** /udfs/favorites/uuids | 
*FilesApi* | [**handle_create_file**](docs/FilesApi.md#handle_create_file) | **POST** /files/{namespace} | 
*FilesApi* | [**handle_export_file**](docs/FilesApi.md#handle_export_file) | **POST** /files/{namespace}/{file}/export | 
*GroupsApi* | [**add_asset**](docs/GroupsApi.md#add_asset) | **POST** /groups/{namespace}/{name}/{asset_namespace}/{asset_name} | 
*GroupsApi* | [**create_group**](docs/GroupsApi.md#create_group) | **POST** /groups/{namespace}/{name} | 
*GroupsApi* | [**delete_group**](docs/GroupsApi.md#delete_group) | **DELETE** /groups/{namespace}/{name} | 
*GroupsApi* | [**list_group**](docs/GroupsApi.md#list_group) | **GET** /groups/{namespace}/{name} | 
*GroupsApi* | [**list_top_level_groups**](docs/GroupsApi.md#list_top_level_groups) | **GET** /groups/{namespace} | 
*GroupsApi* | [**remove_asset**](docs/GroupsApi.md#remove_asset) | **DELETE** /groups/{namespace}/{name}/{asset_namespace}/{asset_name} | 
*GroupsApi* | [**update_group**](docs/GroupsApi.md#update_group) | **PATCH** /groups/{namespace}/{name} | 
*InvitationApi* | [**accept_invitation**](docs/InvitationApi.md#accept_invitation) | **POST** /invitations/{invitation} | 
*InvitationApi* | [**cancel_join_organization**](docs/InvitationApi.md#cancel_join_organization) | **DELETE** /invitations/{invitation}/{organization}/join | 
*InvitationApi* | [**cancel_share_array_by_invite**](docs/InvitationApi.md#cancel_share_array_by_invite) | **DELETE** /invitations/{invitation}/{namespace}/{array}/share | 
*InvitationApi* | [**fetch_invitations**](docs/InvitationApi.md#fetch_invitations) | **GET** /invitations | 
*InvitationApi* | [**join_organization**](docs/InvitationApi.md#join_organization) | **POST** /invitations/{organization}/join | 
*InvitationApi* | [**share_array_by_invite**](docs/InvitationApi.md#share_array_by_invite) | **POST** /invitations/{namespace}/{array}/share | 
*NotebookApi* | [**get_notebook_server_status**](docs/NotebookApi.md#get_notebook_server_status) | **GET** /notebooks/server/{namespace}/status | 
*NotebookApi* | [**shutdown_notebook_server**](docs/NotebookApi.md#shutdown_notebook_server) | **DELETE** /notebooks/server/{namespace} | 
*NotebookApi* | [**update_notebook_name**](docs/NotebookApi.md#update_notebook_name) | **PATCH** /notebooks/{namespace}/{array}/rename | 
*NotebooksApi* | [**notebooks_namespace_array_end_timestamps_get**](docs/NotebooksApi.md#notebooks_namespace_array_end_timestamps_get) | **GET** /notebooks/{namespace}/{array}/end_timestamps | 
*OrganizationApi* | [**add_aws_access_credentials**](docs/OrganizationApi.md#add_aws_access_credentials) | **POST** /credentials/{namespace}/aws | 
*OrganizationApi* | [**add_user_to_organization**](docs/OrganizationApi.md#add_user_to_organization) | **POST** /organizations/{organization}/user | 
*OrganizationApi* | [**check_aws_access_credentials**](docs/OrganizationApi.md#check_aws_access_credentials) | **GET** /credentials/{namespace}/aws | 
*OrganizationApi* | [**check_aws_access_credentials_by_name**](docs/OrganizationApi.md#check_aws_access_credentials_by_name) | **GET** /credentials/{namespace}/aws/{name} | 
*OrganizationApi* | [**create_organization**](docs/OrganizationApi.md#create_organization) | **POST** /organization | 
*OrganizationApi* | [**delete_aws_access_credentials**](docs/OrganizationApi.md#delete_aws_access_credentials) | **DELETE** /credentials/{namespace}/aws/{name} | 
*OrganizationApi* | [**delete_organization**](docs/OrganizationApi.md#delete_organization) | **DELETE** /organizations/{organization} | 
*OrganizationApi* | [**delete_user_from_organization**](docs/OrganizationApi.md#delete_user_from_organization) | **DELETE** /organizations/{organization}/{username} | 
*OrganizationApi* | [**get_all_organizations**](docs/OrganizationApi.md#get_all_organizations) | **GET** /organizations | 
*OrganizationApi* | [**get_organization**](docs/OrganizationApi.md#get_organization) | **GET** /organizations/{organization} | 
*OrganizationApi* | [**get_organization_user**](docs/OrganizationApi.md#get_organization_user) | **GET** /organizations/{organization}/{username} | 
*OrganizationApi* | [**update_aws_access_credentials**](docs/OrganizationApi.md#update_aws_access_credentials) | **PATCH** /credentials/{namespace}/aws/{name} | 
*OrganizationApi* | [**update_organization**](docs/OrganizationApi.md#update_organization) | **PATCH** /organizations/{organization} | 
*OrganizationApi* | [**update_user_in_organization**](docs/OrganizationApi.md#update_user_in_organization) | **PATCH** /organizations/{organization}/{username} | 
*QueryApi* | [**finalize_query**](docs/QueryApi.md#finalize_query) | **POST** /arrays/{namespace}/{array}/query/finalize | 
*QueryApi* | [**get_est_result_sizes**](docs/QueryApi.md#get_est_result_sizes) | **POST** /arrays/{namespace}/{array}/query/est_result_sizes | 
*QueryApi* | [**get_file**](docs/QueryApi.md#get_file) | **GET** /arrays/{namespace}/{array}/query/get_file | 
*QueryApi* | [**submit_query**](docs/QueryApi.md#submit_query) | **POST** /arrays/{namespace}/{array}/query/submit | 
*QueryApi* | [**submit_query_json**](docs/QueryApi.md#submit_query_json) | **POST** /arrays/{namespace}/{array}/query/submit_query_json | 
*SqlApi* | [**run_sql**](docs/SqlApi.md#run_sql) | **POST** /sql/{namespace} | 
*StatsApi* | [**get_tiledb_stats**](docs/StatsApi.md#get_tiledb_stats) | **GET** /.stats | 
*TaskGraphLogsApi* | [**create_task_graph_log**](docs/TaskGraphLogsApi.md#create_task_graph_log) | **POST** /taskgraphs/{namespace}/log | 
*TaskGraphLogsApi* | [**get_task_graph_log**](docs/TaskGraphLogsApi.md#get_task_graph_log) | **GET** /taskgraphs/{namespace}/logs/{id} | 
*TaskGraphLogsApi* | [**list_task_graph_logs**](docs/TaskGraphLogsApi.md#list_task_graph_logs) | **GET** /taskgraphs/logs | 
*TaskGraphLogsApi* | [**update_task_graph_log**](docs/TaskGraphLogsApi.md#update_task_graph_log) | **PATCH** /taskgraphs/{namespace}/logs/{id} | 
*TasksApi* | [**run_sql**](docs/TasksApi.md#run_sql) | **POST** /sql/{namespace} | 
*TasksApi* | [**task_id_get**](docs/TasksApi.md#task_id_get) | **GET** /task/{id} | 
*TasksApi* | [**task_id_result_get**](docs/TasksApi.md#task_id_result_get) | **GET** /task/{id}/result | 
*TasksApi* | [**tasks_get**](docs/TasksApi.md#tasks_get) | **GET** /tasks | 
*UdfApi* | [**delete_udf_info**](docs/UdfApi.md#delete_udf_info) | **DELETE** /udf/{namespace}/{name} | 
*UdfApi* | [**get_udf_info**](docs/UdfApi.md#get_udf_info) | **GET** /udf/{namespace}/{name} | 
*UdfApi* | [**get_udf_info_sharing_policies**](docs/UdfApi.md#get_udf_info_sharing_policies) | **GET** /udf/{namespace}/{name}/share | 
*UdfApi* | [**register_udf_info**](docs/UdfApi.md#register_udf_info) | **POST** /udf/{namespace}/{name} | 
*UdfApi* | [**share_udf_info**](docs/UdfApi.md#share_udf_info) | **PATCH** /udf/{namespace}/{name}/share | 
*UdfApi* | [**submit_generic_udf**](docs/UdfApi.md#submit_generic_udf) | **POST** /udfs/generic/{namespace} | 
*UdfApi* | [**submit_multi_array_udf**](docs/UdfApi.md#submit_multi_array_udf) | **POST** /udfs/arrays/{namespace} | 
*UdfApi* | [**submit_udf**](docs/UdfApi.md#submit_udf) | **POST** /arrays/{namespace}/{array}/udf/submit | 
*UdfApi* | [**udf_namespace_array_end_timestamps_get**](docs/UdfApi.md#udf_namespace_array_end_timestamps_get) | **GET** /udf/{namespace}/{array}/end_timestamps | 
*UdfApi* | [**update_udf_info**](docs/UdfApi.md#update_udf_info) | **PATCH** /udf/{namespace}/{name} | 
*UserApi* | [**add_aws_access_credentials**](docs/UserApi.md#add_aws_access_credentials) | **POST** /credentials/{namespace}/aws | 
*UserApi* | [**add_user_to_organization**](docs/UserApi.md#add_user_to_organization) | **POST** /organizations/{organization}/user | 
*UserApi* | [**check_aws_access_credentials**](docs/UserApi.md#check_aws_access_credentials) | **GET** /credentials/{namespace}/aws | 
*UserApi* | [**check_aws_access_credentials_by_name**](docs/UserApi.md#check_aws_access_credentials_by_name) | **GET** /credentials/{namespace}/aws/{name} | 
*UserApi* | [**confirm_email**](docs/UserApi.md#confirm_email) | **POST** /user/confirm_email | 
*UserApi* | [**create_user**](docs/UserApi.md#create_user) | **POST** /user | 
*UserApi* | [**delete_aws_access_credentials**](docs/UserApi.md#delete_aws_access_credentials) | **DELETE** /credentials/{namespace}/aws/{name} | 
*UserApi* | [**delete_user**](docs/UserApi.md#delete_user) | **DELETE** /users/{username} | 
*UserApi* | [**delete_user_from_organization**](docs/UserApi.md#delete_user_from_organization) | **DELETE** /organizations/{organization}/{username} | 
*UserApi* | [**get_organization_user**](docs/UserApi.md#get_organization_user) | **GET** /organizations/{organization}/{username} | 
*UserApi* | [**get_session**](docs/UserApi.md#get_session) | **GET** /session | 
*UserApi* | [**get_token_scopes**](docs/UserApi.md#get_token_scopes) | **GET** /tokens/scopes | 
*UserApi* | [**get_user**](docs/UserApi.md#get_user) | **GET** /user | 
*UserApi* | [**get_user_with_username**](docs/UserApi.md#get_user_with_username) | **GET** /users/{username} | 
*UserApi* | [**request_token**](docs/UserApi.md#request_token) | **POST** /token | 
*UserApi* | [**reset_user_password**](docs/UserApi.md#reset_user_password) | **POST** /user/password_reset | 
*UserApi* | [**revoke_token**](docs/UserApi.md#revoke_token) | **DELETE** /tokens/{token} | 
*UserApi* | [**tokens_get**](docs/UserApi.md#tokens_get) | **GET** /tokens | 
*UserApi* | [**tokens_session_get**](docs/UserApi.md#tokens_session_get) | **GET** /tokens/session | 
*UserApi* | [**update_aws_access_credentials**](docs/UserApi.md#update_aws_access_credentials) | **PATCH** /credentials/{namespace}/aws/{name} | 
*UserApi* | [**update_user**](docs/UserApi.md#update_user) | **PATCH** /users/{username} | 
*UserApi* | [**update_user_in_organization**](docs/UserApi.md#update_user_in_organization) | **PATCH** /organizations/{organization}/{username} | 


## Documentation For Models

 - [AWSAccessCredentials](docs/AWSAccessCredentials.md)
 - [ActivityEventType](docs/ActivityEventType.md)
 - [Array](docs/Array.md)
 - [ArrayActions](docs/ArrayActions.md)
 - [ArrayActivityLog](docs/ArrayActivityLog.md)
 - [ArrayBrowserData](docs/ArrayBrowserData.md)
 - [ArrayBrowserSidebar](docs/ArrayBrowserSidebar.md)
 - [ArrayEndTimestampData](docs/ArrayEndTimestampData.md)
 - [ArrayFavorite](docs/ArrayFavorite.md)
 - [ArrayFavoritesData](docs/ArrayFavoritesData.md)
 - [ArrayInfo](docs/ArrayInfo.md)
 - [ArrayInfoUpdate](docs/ArrayInfoUpdate.md)
 - [ArrayMetadata](docs/ArrayMetadata.md)
 - [ArrayMetadataEntry](docs/ArrayMetadataEntry.md)
 - [ArraySample](docs/ArraySample.md)
 - [ArraySchema](docs/ArraySchema.md)
 - [ArraySharing](docs/ArraySharing.md)
 - [ArrayTask](docs/ArrayTask.md)
 - [ArrayTaskBrowserSidebar](docs/ArrayTaskBrowserSidebar.md)
 - [ArrayTaskData](docs/ArrayTaskData.md)
 - [ArrayTaskLog](docs/ArrayTaskLog.md)
 - [ArrayTaskStatus](docs/ArrayTaskStatus.md)
 - [ArrayTaskType](docs/ArrayTaskType.md)
 - [ArrayType](docs/ArrayType.md)
 - [Attribute](docs/Attribute.md)
 - [AttributeBufferHeader](docs/AttributeBufferHeader.md)
 - [AttributeBufferSize](docs/AttributeBufferSize.md)
 - [Datatype](docs/Datatype.md)
 - [Dimension](docs/Dimension.md)
 - [DimensionCoordinate](docs/DimensionCoordinate.md)
 - [DimensionTileExtent](docs/DimensionTileExtent.md)
 - [Domain](docs/Domain.md)
 - [DomainArray](docs/DomainArray.md)
 - [Error](docs/Error.md)
 - [FileCreate](docs/FileCreate.md)
 - [FileCreated](docs/FileCreated.md)
 - [FileExport](docs/FileExport.md)
 - [FileExported](docs/FileExported.md)
 - [FilePropertyName](docs/FilePropertyName.md)
 - [FileType](docs/FileType.md)
 - [Filter](docs/Filter.md)
 - [FilterData](docs/FilterData.md)
 - [FilterOption](docs/FilterOption.md)
 - [FilterPipeline](docs/FilterPipeline.md)
 - [FilterType](docs/FilterType.md)
 - [GenericUDF](docs/GenericUDF.md)
 - [Group](docs/Group.md)
 - [GroupCreate](docs/GroupCreate.md)
 - [GroupListing](docs/GroupListing.md)
 - [GroupListingAllOf](docs/GroupListingAllOf.md)
 - [GroupUpdate](docs/GroupUpdate.md)
 - [InlineObject](docs/InlineObject.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [Invitation](docs/Invitation.md)
 - [InvitationArrayShareEmail](docs/InvitationArrayShareEmail.md)
 - [InvitationData](docs/InvitationData.md)
 - [InvitationOrganizationJoinEmail](docs/InvitationOrganizationJoinEmail.md)
 - [InvitationStatus](docs/InvitationStatus.md)
 - [InvitationType](docs/InvitationType.md)
 - [LastAccessedArray](docs/LastAccessedArray.md)
 - [Layout](docs/Layout.md)
 - [MLModelFavorite](docs/MLModelFavorite.md)
 - [MLModelFavoritesData](docs/MLModelFavoritesData.md)
 - [MaxBufferSizes](docs/MaxBufferSizes.md)
 - [MultiArrayUDF](docs/MultiArrayUDF.md)
 - [NamespaceActions](docs/NamespaceActions.md)
 - [NonEmptyDomain](docs/NonEmptyDomain.md)
 - [NotebookFavorite](docs/NotebookFavorite.md)
 - [NotebookFavoritesData](docs/NotebookFavoritesData.md)
 - [NotebookStatus](docs/NotebookStatus.md)
 - [Organization](docs/Organization.md)
 - [OrganizationRoles](docs/OrganizationRoles.md)
 - [OrganizationUser](docs/OrganizationUser.md)
 - [PaginationMetadata](docs/PaginationMetadata.md)
 - [Pricing](docs/Pricing.md)
 - [PricingAggregateUsage](docs/PricingAggregateUsage.md)
 - [PricingCurrency](docs/PricingCurrency.md)
 - [PricingInterval](docs/PricingInterval.md)
 - [PricingType](docs/PricingType.md)
 - [PricingUnitLabel](docs/PricingUnitLabel.md)
 - [PublicShareFilter](docs/PublicShareFilter.md)
 - [Query](docs/Query.md)
 - [QueryJson](docs/QueryJson.md)
 - [QueryRanges](docs/QueryRanges.md)
 - [QueryReader](docs/QueryReader.md)
 - [Querystatus](docs/Querystatus.md)
 - [Querytype](docs/Querytype.md)
 - [ReadState](docs/ReadState.md)
 - [ResultFormat](docs/ResultFormat.md)
 - [SQLParameters](docs/SQLParameters.md)
 - [SSOProvider](docs/SSOProvider.md)
 - [Subarray](docs/Subarray.md)
 - [SubarrayPartitioner](docs/SubarrayPartitioner.md)
 - [SubarrayPartitionerCurrent](docs/SubarrayPartitionerCurrent.md)
 - [SubarrayPartitionerState](docs/SubarrayPartitionerState.md)
 - [SubarrayRanges](docs/SubarrayRanges.md)
 - [Subscription](docs/Subscription.md)
 - [TaskGraphLog](docs/TaskGraphLog.md)
 - [TaskGraphLogStatus](docs/TaskGraphLogStatus.md)
 - [TaskGraphLogsData](docs/TaskGraphLogsData.md)
 - [TaskGraphNodeMetadata](docs/TaskGraphNodeMetadata.md)
 - [TileDBConfig](docs/TileDBConfig.md)
 - [Token](docs/Token.md)
 - [TokenRequest](docs/TokenRequest.md)
 - [TokenScope](docs/TokenScope.md)
 - [UDFActions](docs/UDFActions.md)
 - [UDFArrayDetails](docs/UDFArrayDetails.md)
 - [UDFFavorite](docs/UDFFavorite.md)
 - [UDFFavoritesData](docs/UDFFavoritesData.md)
 - [UDFImage](docs/UDFImage.md)
 - [UDFImageVersion](docs/UDFImageVersion.md)
 - [UDFInfo](docs/UDFInfo.md)
 - [UDFInfoUpdate](docs/UDFInfoUpdate.md)
 - [UDFLanguage](docs/UDFLanguage.md)
 - [UDFSharing](docs/UDFSharing.md)
 - [UDFSubarray](docs/UDFSubarray.md)
 - [UDFSubarrayRange](docs/UDFSubarrayRange.md)
 - [UDFType](docs/UDFType.md)
 - [User](docs/User.md)
 - [Writer](docs/Writer.md)


## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-TILEDB-REST-API-KEY
- **Location**: HTTP header


## BasicAuth

- **Type**: HTTP basic authentication


## OAuth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://oauth2.tiledb.com/oauth2/authorize
- **Scopes**: 
 - **read**: Grants read access
 - **write**: Grants write access
 - **admin**: Grants read and write access to administrative information


## Author




